@@ -75,9 +75,13 @@ def project_from_auth_vars(auth_vars, data):
 
     if api_key:
         try:
-            pm = ProjectMember.objects.get(public_key=api_key)
+            pm = ProjectMember.objects.get_from_cache(public_key=api_key)
         except ProjectMember.DoesNotExist:
             raise APIForbidden('Invalid signature')
+
+        if not pm.is_active or pm.user and not pm.user.is_active:
+            raise APIUnauthorized('Account is not active')
+
         project = pm.project
         secret_key = pm.secret_key
     else:
@@ -109,10 +113,16 @@ def project_from_api_key_and_id(api_key, project_id):
     a project instance or throws APIUnauthorized.
     """
     try:
-        pm = ProjectMember.objects.get(public_key=api_key, project=project_id)
+        pm = ProjectMember.objects.get_from_cache(public_key=api_key)
     except ProjectMember.DoesNotExist:
         raise APIUnauthorized()
 
+    if str(pm.project_id) != str(project_id):
+        raise APIUnauthorized()
+
+    if not pm.is_active or pm.user and not pm.user.is_active:
+        raise APIUnauthorized('Account is not active')
+
     return pm.project
 
 
@@ -121,6 +131,9 @@ def project_from_id(request):
     Given a request returns a project instance or throws
     APIUnauthorized.
     """
+    if not request.user.is_active:
+        raise APIUnauthorized('Account is not active')
+
     try:
         pm = ProjectMember.objects.get(
             user=request.user,
@@ -129,6 +142,9 @@ def project_from_id(request):
     except ProjectMember.DoesNotExist:
         raise APIUnauthorized()
 
+    if not pm.is_active:
+        raise APIUnauthorized()
+
     return pm.project
 
 
