@@ -137,7 +137,7 @@ def poll(request, project):
     view_id = request.GET.get('view_id')
     if view_id:
         try:
-            view = View.objects.get(pk=view_id)
+            view = View.objects.get_from_cache(pk=view_id)
         except View.DoesNotExist:
             return HttpResponseBadRequest()
     else:
@@ -235,7 +235,7 @@ def clear(request, project):
     view_id = request.GET.get('view_id')
     if view_id:
         try:
-            view = View.objects.get(pk=view_id)
+            view = View.objects.get_from_cache(pk=view_id)
         except View.DoesNotExist:
             return HttpResponseBadRequest()
     else:
